summaryrefslogtreecommitdiff
path: root/coverage/summary.py
diff options
context:
space:
mode:
Diffstat (limited to 'coverage/summary.py')
-rw-r--r--coverage/summary.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/coverage/summary.py b/coverage/summary.py
index 696f6b3..df73037 100644
--- a/coverage/summary.py
+++ b/coverage/summary.py
@@ -14,16 +14,16 @@ class SummaryReporter(Reporter):
self.show_missing = show_missing
self.branches = coverage.data.has_arcs()
- def report(self, morfs, omit_prefixes=None, outfile=None, require_prefixes=None):
+ def report(self, morfs, omit_prefixes=None, outfile=None, include_prefixes=None):
"""Writes a report summarizing coverage statistics per module.
`omit_prefixes` is a list of prefixes. CodeUnits that match those prefixes
will be omitted from the list.
`require_prefixes` is a list of prefixes. Only CodeUnits that match those prefixes
will be included in the list.
You are required to pass at most one of `omit_prefixes` and `require_prefixes`.
"""
- self.find_code_units(morfs, omit_prefixes, require_prefixes)
+ self.find_code_units(morfs, omit_prefixes, include_prefixes)
# Prepare the formatting strings
max_name = max([len(cu.name) for cu in self.code_units] + [5])
@@ -14,16 +14,16 @@ class SummaryReporter(Reporter):
`omit_prefixes` is a list of prefixes. CodeUnits that match those prefixes
will be omitted from the list.
- `require_prefixes` is a list of prefixes. Only CodeUnits that match those prefixes
+ `include_prefixes` is a list of prefixes. Only CodeUnits that match those prefixes
will be included in the list.
@@ -14,16 +14,16 @@ class SummaryReporter(Reporter):
will be included in the list.
- You are required to pass at most one of `omit_prefixes` and `require_prefixes`.
+ You are required to pass at most one of `omit_prefixes` and `include_prefixes`.
"""